This directory contains a fork of [Blendify](https://github.com/ptrvilya/blendify), licensed under the GNU GPLv3. The fork was made by István Sárándi for use in the BlendiPose project.

See the following citation for details:

```bibtex
@article{blendify2024,
  title={Blendify -- Python rendering framework for Blender},
  author={Guzov, Vladimir and Petrov, Ilya A and Pons-Moll, Gerard},
  journal={arXiv preprint arXiv:2410.17858},
  year={2024}
}
```